# Copyright (C) 2019-2020 VMware, Inc. All rights reserved.
# -- VMware Confidential
import sha.config

from sha.contrib.metric.daemon_health import DaemonHealth
from sha.contrib.metric.hyperbus_connection_list import HyperbusConnectionList
from sha.contrib.metric.vmk_list import VMKList
from sha.contrib.metric.audit_log_health_for_local_error_status import AuditLogHealthForLocalErrorStatus
from sha.contrib.metric.manager_fqdn_lookup_failure_status import ManagerFqdnLookupFailureStatus

from sha.config import PLATFORM_WINDOWS

__all__ = [
    'HyperbusConnectionList',
    'DaemonHealth',
    'VMKList',
    'AuditLogHealthForLocalErrorStatus',
    'AuditLogHealthForRemoteErrorStatus',
    'ManagerFqdnLookupFailureStatus'
]

if sha.config.NODE_TYPE == sha.config.DIST_ESX:
    from sha.contrib.metric.host_metrics import HostMetrics
    from sha.contrib.metric.mirror_stack_status import MirrorStackStatus
    from sha.contrib.metric.vdr_stats import VdrStats

    esx_metrics = [
        'HostMetrics',
        'MirrorStackStatus',
        'VdrStats',
    ]
    __all__.extend(esx_metrics)

if sha.config.node_type_is(sha.config.DIST_EDGE, sha.config.DIST_UA, sha.config.DIST_GM,
                           sha.config.DIST_PUBLIC_CLOUD_GATEWAY):
    from sha.contrib.metric.audit_log_health_for_remote_error_status import AuditLogHealthForRemoteErrorStatus
    __all__.extend('AuditLogHealthForRemoteErrorStatus')

if sha.config.node_type_is(sha.config.DIST_UA, sha.config.DIST_GM):
    from sha.contrib.metric.manager_fqdn_reverse_lookup_failure_status import ManagerFqdnReverseLookupFailureStatus
    __all__.extend('ManagerFqdnReverseLookupFailureStatus')

if sha.config.NODE_TYPE == sha.config.DIST_EDGE:
    from sha.contrib.metric.edge_fw_stats import EdgeFWStats
    from sha.contrib.metric.edge_fw_conn import EdgeFWConn
    from sha.contrib.metric.edge_ipsec_vpn_stats import EdgeIpsecVpnStats
    from sha.contrib.metric.edge_status import EdgeStatus
    from sha.contrib.metric.edge_sr_state import EdgeSrState
    from sha.contrib.metric.sys_stats import SysStats
    from sha.contrib.metric.edge_dp_stats import EdgeDpStats
    from sha.contrib.metric.edge_lr_port_stats import EdgeLRPortStats
    from sha.contrib.metric.tls_stats import TlsStats
    from sha.contrib.metric.lb_status import LbStatus
    from sha.contrib.metric.idps_stats import IdpsStats

    edge_metrics = [
        'EdgeFWStats',
        'EdgeFWConn',
        'EdgeIpsecVpnStats',
        'EdgeStatus',
        'EdgeSrState',
        'SysStats',
        'EdgeDpStats',
        'EdgeLRPortStats',
        'TlsStats',
        'LbStatus',
        'IdpsStats',
    ]
    __all__.extend(edge_metrics)

elif sha.config.NODE_TYPE == sha.config.DIST_ESX:
    from sha.contrib.metric.lb_status import LbStatus

    esx_metrics = [
        'LbStatus',
    ]
    __all__.extend(esx_metrics)

elif sha.config.NODE_TYPE == sha.config.DIST_UA:
    from sha.contrib.metric.top_process_list import TopProcessList
    from sha.contrib.metric.ua_node_latency_list import UaNodeLatencyList
    from sha.contrib.metric.sys_stats import SysStats

    ua_metrics = [
        'TopProcessList',
        'UaNodeLatencyList',
        'SysStats',
    ]

    __all__.extend(ua_metrics)

# For all 3 edge types
if sha.config.node_type_is(sha.config.DIST_EDGE, sha.config.DIST_AUTONOMOUS_EDGE,
                           sha.config.DIST_PUBLIC_CLOUD_GATEWAY):
    from sha.contrib.metric.edge_mgmt_interface_status import EdgeMgmtInterface
    from sha.contrib.metric.rcu_event_status import EdgeRcuBlock

    __all__.append('EdgeMgmtInterface')
    __all__.append('EdgeRcuBlock')


if sha.config.node_type_is(sha.config.DIST_ESX, sha.config.DIST_KVM, sha.config.DIST_BMS) \
        and sha.config.SYSTEM != PLATFORM_WINDOWS:
    from sha.contrib.metric.nestdb_status import NestdbStatus
    __all__.extend('NestdbStatus')
